(convert file & {:keys [output processing pool]})Converts input file into :output based on a collection of processing commands.
If output is not provided, input file get overriden.
Returns a promise which resolves to either transformed image file or (in case of failure) to an error.
Converts input file into `:output` based on a collection of processing commands. If output is not provided, input file get overriden. Returns a promise which resolves to either transformed image file or (in case of failure) to an error.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |